OutTPmsm <- function(data, ...) {
	return(data);
} # OutTPmsm
